---
name: Bug report
about: Create a report to help us improve
title: ''
labels: 'bug'
assignees: ''

---
## Description
(A clear and concise description of what the bug is.)

## To Reproduce
(Please provide minimal example of code snippet that reproduces the error. For existing examples, please provide link.)

```python
put code here
```

## Error message or code output
(Paste the complete error message, including stack trace, or the undesired output that the above snippet produces.)

```
put error or undesired output here
```

## Environment
- Operating system:
- Python version:
- GluonTS version:
- MXNet version:

(Add as much information about your environment as possible, e.g. dependencies versions.)
